import { ApiResponse, RequestOptions } from '../core';
import { ListMerchantsResponse } from '../models/listMerchantsResponse';
import { RetrieveMerchantResponse } from '../models/retrieveMerchantResponse';
import { BaseApi } from './baseApi';
export declare class MerchantsApi extends BaseApi {
    /**
     * Provides details about the merchant associated with a given access token.
     *
     * The access token used to connect your application to a Square seller is associated
     * with a single merchant. That means that `ListMerchants` returns a list
     * with a single `Merchant` object. You can specify your personal access token
     * to get your own merchant information or specify an OAuth token to get the
     * information for the merchant that granted your application access.
     *
     * If you know the merchant ID, you can also use the [RetrieveMerchant]($e/Merchants/RetrieveMerchant)
     * endpoint to retrieve the merchant information.
     *
     * @param cursor The cursor generated by the previous response.
     * @return Response from the API call
     */
    listMerchants(cursor?: number, requestOptions?: RequestOptions): Promise<ApiResponse<ListMerchantsResponse>>;
    /**
     * Retrieves the `Merchant` object for the given `merchant_id`.
     *
     * @param merchantId  The ID of the merchant to retrieve. If the string "me" is supplied as the ID, then
     *                              retrieve the merchant that is currently accessible to this call.
     * @return Response from the API call
     */
    retrieveMerchant(merchantId: string, requestOptions?: RequestOptions): Promise<ApiResponse<RetrieveMerchantResponse>>;
}
